@@ -1,7 +1,7 @@
 package Log::Any::App;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 # i need this to run on centos 5.x. otherwise all my other servers are debian
 # 5.x and 6.x+ (perl 5.010).
@@ -14,7 +14,6 @@ use File::Spec;
 use Log::Any::IfLOG;
 use Log::Any::Adapter;
 
-
 use vars qw($dbg_ctx);
 
 our %PATTERN_STYLES = (
@@ -45,11 +44,11 @@ sub _ifdef {
 
 # j=as json (except the last default)
 sub _ifdefj {
-    require JSON;
+    require JSON::MaybeXS;
 
     my $def = pop @_;
     for (@_) {
-        return JSON::decode_json($_) if defined($_);
+        return JSON::MaybeXS::decode_json($_) if defined($_);
     }
     $def;
 }
@@ -1154,7 +1153,7 @@ Log::Any::App - An easy way to use Log::Any in applications
 
 =head1 VERSION
 
-This document describes version 0.52 of Log::Any::App (from Perl distribution Log-Any-App), released on 2016-01-19.
+This document describes version 0.53 of Log::Any::App (from Perl distribution Log-Any-App), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -2253,7 +2252,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Ap
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Log-Any-App>.
+Source repository is at L<https://github.com/sharyanto/perl-Log-Any-App>.
 
 =head1 BUGS
 
